@@ -48,7 +48,7 @@ class FileSystemManager():
                   'gpt': '8300',
                   'label': '-L {labelname}',
                   'msdos': '83',
-                  'ssd': ['ssd', 'space_cache'],
+                  'ssd': ['ssd'],
                   'type': ['hdd', 'usb-hdd'],
                   'compress': None,
                   'compatible': ['btrfs-compress']},
@@ -99,7 +99,7 @@ class FileSystemManager():
                   'gpt': '8300',
                   'label': '-L {labelname}',
                   'msdos': '83',
-                  'ssd': ['ssd', 'space_cache'],
+                  'ssd': ['ssd'],
                   'type': ['hdd', 'usb-hdd'],
                   'compatible': ['btrfs']},
         'ext4': {'defaultopt': defaultOpt,
