@@ -405,7 +405,7 @@ class VariableOsInstallFbResolution(ResolutionVariable):
         try:
             return get_best_nearest_resolution(
                 x11res, hwinfo.resolutions()) or self.fallback_resolution
-        except device.HwinfoError:
+        except (ZeroDivisionError, device.HwinfoError):
             return self.fallback_resolution
 
 class VariableClGrubImageHash(ReadonlyVariable):
